@@ -1,10 +1,10 @@
 ##----------------------------------------------------------------------------
 ## Cookies API for Server & Client - ~/lib/Cookie.pm
-## Version v0.1.5
+## Version v0.1.6
 ## Copyright(c) 2021 DEGUEST Pte. Ltd.
 ## Author: Jacques Deguest <jack@deguest.jp>
 ## Created 2019/10/08
-## Modified 2021/11/25
+## Modified 2021/12/07
 ## You can use, copy, modify and  redistribute  this  package  and  associated
 ## files under the same terms as Perl itself.
 ##----------------------------------------------------------------------------
@@ -22,12 +22,13 @@ BEGIN
     use URI::Escape ();
     use overload (
         '""'     => \&as_string,
+        bool     => sub{ return( $_[0] ) },
         # '""'     => sub{ $_[0]->as_string },
         'eq'     => \&same_as,
         '=='     => \&same_as,
         fallback => 1,
     );
-    our $VERSION = 'v0.1.5';
+    our $VERSION = 'v0.1.6';
     our $SUBS;
     our $COOKIE_DEBUG = 0;
     use constant CRYPTX_VERSION => '0.074';
@@ -99,6 +100,7 @@ sub algo
                 my $o = Crypt::Mode::CBC->new( $algo ) ||
                     return( $self->error( "Unsupported algorithm \"$algo\"" ) );
                 $self->_set_get_scalar_as_object( 'algo', $algo );
+                $self->reset(1);
             }
             catch( $e )
             {
@@ -299,7 +301,7 @@ sub decrypt
 
 sub discard { return( shift->_set_get_boolean( 'discard', @_ ) ); }
 
-sub domain { return( shift->reset->_set_get_scalar_as_object( 'domain', @_ ) ); }
+sub domain { return( shift->reset(@_)->_set_get_scalar_as_object( 'domain', @_ ) ); }
 
 # To expire a cookie, the domain and path must match that was previously set
 # <https://datatracker.ietf.org/doc/html/rfc6265#section-3.1>
@@ -310,7 +312,7 @@ sub elapse
     return( $self );
 }
 
-sub encrypt { return( shift->reset->_set_get_boolean( 'encrypt', @_ ) ); }
+sub encrypt { return( shift->reset(@_)->_set_get_boolean( 'encrypt', @_ ) ); }
 
 # sub expires { return( shift->APR::Request::Cookie::expires( @_ ) ); }
 # https://developer.mozilla.org/en-US/docs/Web/HTTP/Headers/Date
@@ -320,7 +322,7 @@ sub expires
     my $self = shift( @_ );
     if( @_ )
     {
-        $self->reset( @_ );
+        $self->reset(1);
         my $exp = shift( @_ );
         $self->message( 3, "Received expiration value of '", ( $exp // '' ), "' (", ( defined( $exp ) ? 'defined' : 'undefined' ), ")." ) if( $COOKIE_DEBUG );
         my $dt;
@@ -405,11 +407,11 @@ sub host { return( shift->domain( @_ ) ); }
 
 sub host_only { return( shift->implicit( @_ ) ); }
 
-sub http_only { return( shift->reset->_set_get_boolean( 'http_only', @_ ) ); }
+sub http_only { return( shift->reset(@_)->_set_get_boolean( 'http_only', @_ ) ); }
 
 sub httponly { return( shift->http_only( @_ ) ); }
 
-sub implicit { return( shift->reset->_set_get_boolean( 'implicit', @_ ) ); }
+sub implicit { return( shift->reset(@_)->_set_get_boolean( 'implicit', @_ ) ); }
 
 # For cookie encryption
 sub initialisation_vector { return( shift->_set_get_scalar_as_object( 'initialisation_vector', @_ ) ); }
@@ -513,7 +515,7 @@ sub match_host
     return(0);
 }
 
-# sub max_age { return( shift->reset->_set_get_scalar( 'max_age', @_ ) ); }
+# sub max_age { return( shift->reset(@_)->_set_get_scalar( 'max_age', @_ ) ); }
 sub max_age
 {
     my $self = shift( @_ );
@@ -584,9 +586,9 @@ sub name
     return( $self->_set_get_scalar_as_object( 'name' ) );
 }
 
-sub path { return( shift->reset->_set_get_scalar_as_object( 'path', @_ ) ); }
+sub path { return( shift->reset(@_)->_set_get_scalar_as_object( 'path', @_ ) ); }
 
-sub port { return( shift->reset->_set_get_number( 'port', @_ ) ); }
+sub port { return( shift->reset(@_)->_set_get_number( 'port', @_ ) ); }
 
 sub reset
 {
@@ -620,13 +622,13 @@ sub same_as
     return(1);
 }
 
-sub same_site { return( shift->reset->_set_get_scalar_as_object( 'same_site', @_ ) ); }
+sub same_site { return( shift->reset(@_)->_set_get_scalar_as_object( 'same_site', @_ ) ); }
 
 sub samesite { return( shift->same_site( @_ ) ); }
 
-sub secure { return( shift->reset->_set_get_boolean( 'secure', @_ ) ); }
+sub secure { return( shift->reset(@_)->_set_get_boolean( 'secure', @_ ) ); }
 
-sub sign { return( shift->reset->_set_get_boolean( 'sign', @_ ) ); }
+sub sign { return( shift->reset(@_)->_set_get_boolean( 'sign', @_ ) ); }
 
 sub uri
 {
@@ -651,7 +653,7 @@ sub uri
     return( $self->_set_get_uri( 'uri' ) );
 }
 
-sub value { return( shift->reset->_set_get_scalar_as_object( 'value', @_ ) ); }
+sub value { return( shift->reset(@_)->_set_get_scalar_as_object( 'value', @_ ) ); }
 
 # Deprecated. Was a version 2 cookie spec: https://developer.mozilla.org/en-US/docs/Web/HTTP/Headers/Set-Cookie2
 sub version { return( shift->_set_get_number( 'version', @_ ) ); }
@@ -836,7 +838,7 @@ Cookie - Cookie Object with Encryption or Signature
 
 =head1 VERSION
 
-    v0.1.5
+    v0.1.6
 
 =head1 DESCRIPTION
 
@@ -1415,7 +1417,7 @@ For example:
 
 See also L<modperl testing documentation|https://perl.apache.org/docs/general/testing/testing.html>
 
-But, if for some reason, you do not want to perform the mod_perl tests, you can call use C<NO_MOD_PERL=1> when calling C<perl Makefile.PL>, such as:
+But, if for some reason, you do not want to perform the mod_perl tests, you can use C<NO_MOD_PERL=1> when calling C<perl Makefile.PL>, such as:
 
     NO_MOD_PERL=1 perl Makefile.PL
     make
